module Ecom
  module Model
    module ResourceTypeable
      extend ActiveSupport::Concern

      included do
        before_action :set_clazz
      end

      def index
        render json: ResourceTypeSerializer.new(@clazz.all)
      end

      def create
        resource_type = @clazz.new(resource_type_params)
        if resource_type.save
          render json: ResourceTypeSerializer.new(resource_type), status: :created
        else
          render json: { success: false, errors: resource_type.errors }, status: :unprocessable_entity
        end
      end

      def update
        resource_type = @clazz.find(params[:id])
        if resource_type.update(resource_type_params)
          render json: ResourceTypeSerializer.new(resource_type)
        else
          render json: { success: false, errors: resource_type.errors }, status: :unprocessable_entity
        end
      end

      private

      def set_clazz
        @clazz = "Ecom::Model::#{controller_name.classify}".constantize
      end

      def resource_type_params
        params.require(:resource_type).permit(:code, :name, :base_unit)
      end
    end
  end
end