module Ecom
  module Model
    class TaskTemplate < ApplicationRecord
      has_ancestry

      belongs_to :task_template_type
      has_one :work_product_template
      has_and_belongs_to_many :resource_types, join_table: 'ecom_model_task_templates_resource_types'

      validates :name, :code, presence: true
      validates :code, uniqueness: true
      delegate(:name, to: :task_template_type, prefix: true)

      def full_name
        parent_name = parent&.name
        return name unless parent_name

        "#{name} - #{parent_name}"
      end

      def crew_types
        resource_types.where(type: 'Ecom::Model::CrewType')
      end

      def material_types
        resource_types.where(type: 'Ecom::Model::MaterialType')
      end

      def equipment_types
        resource_types.where(type: 'Ecom::Model::EquipmentType')
      end
    end
  end
end
